# AIC

[![CI](https://github.com/ShaojieJiang/aic-core/actions/workflows/ci.yml/badge.svg?event=push)](https://github.com/ShaojieJiang/aic-core/actions/workflows/ci.yml?query=branch%3Amain)
[![Coverage](https://coverage-badge.samuelcolvin.workers.dev/ShaojieJiang/aic-core.svg)](https://coverage-badge.samuelcolvin.workers.dev/redirect/ShaojieJiang/aic-core)
[![PyPI](https://img.shields.io/pypi/v/aic-core.svg)](https://pypi.python.org/pypi/aic-core)
